<TS language="sl_SI" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>O Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Ustvari nov naslov</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopiraj trenutno izbrani naslov v odložišče</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Prikaži &amp;QR kodo</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Podpišite sporo?ilo, kot dokazilo lastništva Gridcoin naslova</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Podpiši &amp;sporo?ilo</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Potrdi sporo?ilo, da zagotovite, da je bilo podpisano z izbranim Gridcoin naslovom</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Potrdi sporo?ilo</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Izbriši trenutno označeni naslov  iz seznama</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Imenik</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>To so vaši Gridcoin naslovi za prejemanje pla?il. Priporo?eno je da vsakemu pošiljatelju namenite drugega in tako dobite ve?ji pregled nad svojimi nakazili.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>I&amp;zbriši</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopiraj &amp;oznako</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Uredi</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Izvozi podatke imenika</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Napaka pri izvozu datoteke</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Napaka pri pisanju na datoteko %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ni oznake)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Vnos gesla</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Vnesite geslo</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Novo geslo</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ponovite novo geslo</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Služi kot onemogo?enje pošiljanja prostega denarja, v primerih okužbe operacijskega sistema. Ne ponuja prave zaš?ite.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Samo za staking.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Šifriraj denarnico</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>To dejanje zahteva geslo za odklepanje vaše denarnice.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Odkleni denarnico</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Zamenjaj geslo</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Vnesite staro in novo geslo denarnice.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potrdi šifriranje denarnice</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Opozorilo: ?e šifrirate svojo denarnico in izgubite svoje geslo, boste &lt;b&gt; IZGUBILI VSE SVOJE KOVANCE&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ali ste prepri?ani, da želite šifrirati vašo denarnico?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Denarnica šifrirana</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin se bo sedaj zaprl, da dokon?a proces šifriranje. Pomnite, da tudi šifriranje vaše denarnice ne more v celoti zaš?ititi vaših kovancev pred krajo z zlonamernimi programi in ra?unalniškimi virusi, ?e ti okužijo vaš ra?unalnik.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>POMEMBNO: Vsaka predhodna varnostna kopija datoteke denarnice mora biti nadomeš?ena z novo datoteko šifrirane denarnice. Zaradi varnostnih razlogov bodo namre? prejšnje varnostne kopije datoteke nešifrirane denarnice postale neuporabne takoj ko boste pri?eli uporabljati novo, šifrirano denarnico.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Šifriranje denarnice je spodletelo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Šifriranje denarnice spodletelo je zaradi notranje napake. Vaša denarnica ni šifrirana.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Vnešeno geslo se ne ujema</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Odklep denarnice spodletel</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Geslo za dešifriranje denarnice, ki ste ga vnesli, ni pravilno.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Geslo denarnice je bilo uspešno spremenjeno.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Opozorilo: imate prižgan Cap Lock</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>Prišlo je do usodne napake. Program Gridcoin se ne more ve? varno nadaljevati in se bo zato zaprl. </translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Denarnica</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>Pre&amp;gled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Oglejte si splošne informacije o vaši denarnici</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Pošlji</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Pošlji kovance na Gridcoin naslov</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>P&amp;rejmi</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Prikaži seznam naslovov za prejemanje pla?il. </translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Brskajte po zgodovini transakcij</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Uredi seznam shranjenih naslovov in oznak</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>I&amp;zhod</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Ustavite program</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;O Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Pokaži informacije o Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Možnosti ...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Spremeni nastavitve za Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Prikaži / Skrij</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Šifriraj denarnico ...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Spremeni geslo ...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Spremenite geslo za šifriranje denarnice</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Odkleni denarnico...</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Odkleni denarnico</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Zakleni denarnico</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Zakleni denarnico</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Podpiši &amp;sporočilo ...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Preveri sporočilo ...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Izvozi...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Izvozi podatke v izbranem zavihku v datoteko</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Razhroščevalno okno</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Odprite razhroščevalno in diagnostično konzolo</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavitve</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoč</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Gridcoin program</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Posodobljeno</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Dohitevam omrežje ...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Zadnji prejeti blok je bil ustvarjen %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Ta transakcija je prekora?ila limit. Še vedno jo lahko pošljete za pla?ilo %1 transakcije, ki je pla?ano vsem delom omrežja kot deležnina in pomaga zagotavljati njegovo varnost. Ali želite pla?ati provizijo?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Potrdi transakcijsko provizijo</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Odlivi</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Prilivi</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>Rokovanje z URI</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>URI ne more biti raz?lenjen! To se lahko zgodi zaradi neveljavnega Gridcoin naslova ali slabih parametrov URI.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Denarnica je &lt;b&gt;šifrirana&lt;/b&gt; in trenutno &lt;b&gt;zaklenjena&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Napravi varnostno kopijo denarnice</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Datoteka denarnice (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Ustvarjanje varnostne kopije je spodeltelo </translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Prišlo je do napake ob poskušanju shranjevanja datoteke denarnice na novo lokacijo.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Omrežno Opozorilo</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Št.vhodov:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Št.bajtov:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Znesek:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Provizija:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Kontrola kovancev</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Nizek output:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po proviziji:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vračilo:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Znesek</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Potrditve</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potrjeno</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiraj naslov</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiraj oznako</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj koli?ino</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopiraj ID transakcije</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiraj koli?ino</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiraj provizijo</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiraj po proviziji</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiraj bite</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopiraj nizek output:</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiraj spremembo</translation>
    </message>
    <message>
        <source>DUST</source>
        <translation>PRAH</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>da</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Ta oznakla se obarva rde?e, ?e je transakcija ve?ja od 10000 bajtov.

 To pomeni, da je zahtevana provizija vsaj %1 na kb.

 Lahko variira +/- 1 Bajt na vnos.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Ta oznaka se obarva rde?e, ?e prejemnik dobi koli?ino manjšo od %1.

 To pomeni, da je potrebna vsaj %2 provizija.  

 Zneski pod 0.546 krat minimalna transakcijska provizija so prikazani kot PRAH.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Ta oznakla se obarva rde?e, ?e je sprememba manjša od %1.

 To pomeni, da je zahtevana provizija vsaj %2.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ni oznake)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>spremeni iz %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(spremeni)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Uredi naslov</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Oznaka</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>Oznaka povezana s tem vnosom v imeniku</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>Naslov povezan s tem vnosom v imeniku. Spremenite ga lahko le za naslove odlivov.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Naslov</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nov naslov za prilive</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nov naslov za odlive</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Uredi naslov za prilive</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Uredi naslov za odlive</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>Vneseni naslov "%1" ni veljaven Gridcoin naslov.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Vnešeni naslov "%1" je že v imeniku.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Denarnice ni bilo mogo?e odkleniti.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Ustvarjanje novega klju?a je spodletelo.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>razli?ica</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uporaba:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>možnosti ukazne vrstice</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Glavno</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Omrežje</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Preslikaj vrata z uporabo &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Avtomati?no zaženi Gridcoin ob zagonu sistema.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Zaženi Gridcoin ob prijavi v sistem</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Avtomati?no odpri vrata na routerju za Gridcoin program. To deluje le ?e vaš router podpira UPnP in je ta omogo?en. </translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>IP naslov proxy strežnika (npr. 127.0.0.1)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Vrata:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Vrata posredniškega strežnika (npr. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Pomanjšaj aplikacijo, ko je okno zaprto. Ko je omogo?ena ta možnost lahko aplikacijo zaprete le tako, da izberete Izhod v meniju.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>Tu lahko nastavite jezik uporabniškega vmesnika. Nastavitve bodo pri?ele delovati ob ponovnem zagonu Gridcoin aplikacije. </translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Izbira prikaza Gridcoin naslovov v seznamu transakcij.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Prikaz naslovov v seznamu transakcij</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>O&amp;kno</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Uporabi</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Po minimiranju okna samo prikaži ikono programa v pladnju.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimiraj na pladenj namesto na opravilno vrstico</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>Ob zapiranju okno zgolj m&amp;inimiraj</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Prikaz</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Jezik uporabniškega vmesnika:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Enota za prikaz zneskov:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Izberite privzeto mersko enoto za prikaz v uporabniškem vmesniku in pri pošiljanju kovancev.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Potrdi</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Prekliči</translation>
    </message>
    <message>
        <source>default</source>
        <translation>privzeto</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Ta nastavitev bo pri?ela delovati ob ponovnem zagonu Gridcoin aplikacije</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Vnešeni naslov posredniškega strežnika ni veljaven.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Oblika</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Na voljo:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Skupni znesek vaših sredstev, s katerimi lahko prosto razpolagate</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Nedozorelo:</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Prikazane informacije so morda zastarele. Vaša denarnica se avtomati?no sinhronizira z Gridcoin omrežjem, ko je vzpostavljena povezava, toda ta proces še ni bil zaklju?en.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Znesek transakcij, ki še niso bile potrjene in se še ne upoštevajo v trenutnem stanju na ra?unu.</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Skupaj:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Trenutna vsota vseh vaših sredstev</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>QR koda </translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Zahtevaj pla?ilo</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Oznaka:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Sporo?ilo:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Znesek:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Shrani kot...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Napaka pri šifriranju URI v QR kodo.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>Vnesen znesek je neveljaven, prosimo preverite vnos.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI predolg, skušajte zmanjšati besedilo oznake/sporo?ila.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Shrani QR kodo</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Različica odjemalca</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informacije</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Čas zagona</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Število povezav</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Veriga blokov</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Trenutno število blokov</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Čas zadnjega bloka</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Odpri</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Počisti</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Omrežni promet</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Promet</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Dohodnih:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Odhodnih:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Razhroščevalni dnevnik</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Počisti konzolo</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>Na testnet</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Ocena vseh blokov</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Odpri Gridcoin datoteko zapisov odpravljanja napak iz trenutnega direktorija podatkov. ?e so datoteke zapisov velike, to lahko traja nekaj sekund.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Možnosti ukazne vrstice.</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Prikaži</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Ime odjemalca</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Uporabite tipki gor in dol za navigacijo po zgodovini ukazov. Uporabite &lt;b&gt;Ctrl-L&lt;/b&gt; za izbris zaslona in zgodovine ukazov.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Vtipkajte &lt;b&gt;help&lt;/b&gt; za pregled razpoložljivih ukazov.</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KiB</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MiB</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GiB</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Pošlji</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Vhodi ...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>samodejno izbrani</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Premalo sredstev!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Št.vhodov:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Št.bajtov:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Znesek:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Provizija:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Nizek output:</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ne</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Po proviziji:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Sprememba</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>izbira spremembe naslova</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Odstrani vsa polja transakcij</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Pošlji več prejemnikom hkrati</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Dodaj &amp;prejemnika</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Počisti &amp;vse </translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Potrdi pošiljanje</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Pošlji</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopiraj koli?ino</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj koli?ino</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopiraj provizijo</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopiraj po proviziji</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopiraj bite</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopiraj nizek output</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopiraj spremembo</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Potrdi odliv kovancev </translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Ali ste prepri?ani, da želite poslati %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>in</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Prejemnikov naslov ni veljaven, prosimo ?e ga ponovno preverite.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Koli?ina za pla?ilo mora biti ve?ja od 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Koli?ina presega vaše dobroimetje</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Seštevek presega vaše stanje na ra?unu ko je vklju?en %1 provizije na transakcijo. </translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Najdena kopija naslova, možnost pošiljanja na vsakega izmed naslov le enkrat ob pošiljanju.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Napaka: Ustvarjanje transakcije spodletelo</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Napaka: Transakcija je bila zavrnjena. To se je lahko zgodilo, ?e so bili kovanci v vaši denarnici že zapravljeni, na primer ?e ste uporabili kopijo wallet.dat in so bili kovanci zapravljeni v kopiji, a tu še niso bili ozna?eni kot zapravljeni.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ni oznake)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>OPOZORILO: Neveljaven Gridcoin naslov</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>OPOZORILO: neznana sprememba naslova</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Znesek:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Prejemnik &amp;plačila:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Sporočilo:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Oznaka:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Oblika</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Prilepite naslov iz odložišča</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Izberite naslov iz imenika</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Odstrani tega prejemnika</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Vnesite oznako za ta naslov, ki bo shranjena v imenik</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Podpiši / preveri sporočilo</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Podpiši sporočilo</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Sporo?ila lahko podpišete s svojim naslovom, da dokažete lastništvo. Bodite previdni, saj vas lahko phishing napadi skušajo pretentati v to, da jim prepišete svojo identiteto. Podpisujte le jasne in razlo?ne izjave, s katerimi se strinjate.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Izberite naslov iz imenika</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Prilepite naslov iz odložišča</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Vnesite sporočilo, ki ga želite podpisati</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopiranje trenutnega podpisa na sistemsko odložišče.</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Podpišite sporo?ilo, kot dokazilo lastništva Gridcoin naslova</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Podpiši &amp;sporočilo</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Počisti vsa polja za vnos v oknu za podpisovanje</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Počisti &amp;vse </translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Preveri sporočilo</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Vnesite naslov za podpis, sporo?ilo (poskribte da to?no skopirate presledke med vrsticami, ?rkami, itd.) in podpis spodaj, da potrdite sporo?ilo Da se ognete napadom posrednika, bodite pozorni, da ne boste v podpisu ugledali ve?, kot je v podpisanemu sporo?ilu samem.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Potrdite sporo?ilo, da zagotovite, da je bilo podpisano z izbranim Gridcoin naslovom</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Počisti vsa polja za vnos v oknu za preverjanje</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Kliknite "Podpiši sporo?ilo" za ustvaritev podpisa</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Vnesite Gridcoin podpis</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Vnešeni naslov ni veljaven.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Prosimo preverite naslov in poizkusite znova.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Vnešen naslov se ne nanaša na klju?.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Odklepanje denarnice je bilo prekinjeno.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Zasebni klju? vnešenega naslov ni na voljo.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Podpisovanje sporo?ila spodletelo.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Sporo?ilo podpisano.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Ni bilo mogo?e dešifrirati podpisa.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Prosimo preverite podpis in poizkusite znova.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Podpis se ni ujemal s povzetkom sporo?ila.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Pregledovanje sporo?ila spodletelo.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Sporo?ilo pregledano.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Odpri enoto %1</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>sporen</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/nepotrjeno</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 potrdil</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stanje</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, še ni bil uspešno predvajan</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Izvor</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Pošiljatelj</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>neznano</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Prejemnik</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>lasten naslov</translation>
    </message>
    <message>
        <source>label</source>
        <translation>oznaka</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kredit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>ni bilo sprejeto</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Dolg</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Provizija transakcije</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neto koli?ina</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Sporo?ilo</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Opomba</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Koli?ina</translation>
    </message>
    <message>
        <source>true</source>
        <translation>pravilno</translation>
    </message>
    <message>
        <source>false</source>
        <translation>nepravilno</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Podrobnosti transakcije</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>V tem podoknu so prikazane podrobnosti o transakciji</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Koli?ina</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Odpri enoto %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Nepovezan</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Nepotrjeno</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Potrjeno (%1 potrdil)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Sporen</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generirano, toda ne sprejeto</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Prejeto z</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Prejeto od</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslano</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Izpla?ilo sebi</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(ni na voljo)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Stanje transakcije. Zapeljite z miško ?ez to polje za prikaz števila potrdil. </translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum in ?as, ko je transakcija bila prejeta.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Vrsta transakcije.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Naslov prejemnika transakcije.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Koli?ina odlita ali prilita dobroimetju.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Danes</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Ta teden</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ta mesec</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Prejšnji mesec</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>To leto</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Obmo?je ...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Prejeto z</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Poslano</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Samemu sebi</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minirano</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Drugo</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimalna koli?ina</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopiraj naslov</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopiraj oznako</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiraj koli?ino</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopiraj ID transakcije</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Uredi oznako</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Prikaži podrobnosti transakcije</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Izvozi podatke transakcij</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potrjeno</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Koli?ina</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Napaka pri izvažanju podatkov</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Napaka pri pisanju na datoteko %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Obmo?je:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>za</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Pošiljanje...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Prišlo je do napake pri nastavljanju RPC porta %u za vhodne povezave na IPv6: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Prišlo je do napake pri nastavljanju RPC porta %u za vhodne povezave na IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Uporaba:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Prikaži ukaze</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Prikaži pomo? za ukaz</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Opozorilo: -paytxfee je nastavljen zelo visoko! To je transakcijska provizija, ki jo boste pla?ali ob pošiljanju transakcije.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Opozorilo: wallet.dat je pokvarjena, podatki rešeni! Originalna wallet.dat je bila shranjena kot denarnica. {timestamp}.bak v %s; ?e imate napa?no prikazano stanje na ra?unu ali v transakcijah prenovite datoteko z varnostno kopijo. </translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Opozorilo: napaka pri branju wallet.dat! Vsi klju?i so bili pravilno prebrani, podatki o transakciji ali imenik vnešenih naslovov so morda izgubljeni ali nepravilni.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Napaka: Ustvarjanje transakcije spodletelo</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Napaka: Transakcija je bila zavrnjena. To se je lahko zgodilo, ?e so bili kovanci v vaši denarnici že zapravljeni, na primer ?e ste uporabili kopijo wallet.dat in so bili kovanci zapravljeni v kopiji, a tu še niso bili ozna?eni kot zapravljeni.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ni mogoče poslušati na nobenih vratih. Če to zares želite, uporabite opcijo -listen=0.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Za uporabo %s opcije</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Nastaviti morate rpcpassword=&lt;password&gt; v konfiguracijski datoteki: 
%s
?e datoteka ne obstaja, jo ustvarite z lastniškimi dovoljenji za datoteke.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Gridcoin razli?ica</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Neveljavni znesek za -paytxfee=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Neveljavni znesek za -miniput=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Denarnica %s se nahaja zunaj datote?nega imenika %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Potrdite neopore?nost baze podatkov...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Napaka pri zagonu podatkovne baze okolja %s! Za popravilo, NAPRAVITE VARNOSTNO KOPIJO IMENIKA, in iz njega odstranite vse razen datoteke wallet.dat</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat poškodovana, neuspešna obnova</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Neveljaven naslov -proxy: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Neveljaven -tor naslov: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Ni mogo?e dolo?iti -bind naslova: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Ni mogo?e dolo?iti -externalip naslova: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Neveljavni znesek za -reservebalance=&lt;amount&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Napaka pri nalaganju blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Napaka pri nalaganju wallet.dat: denarnica pokvarjena</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Napaka pri nalaganju wallet.dat: denarnica zahteva novejšo verzijo Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>Denarnica mora biti prepisana: ponovno odprite Gridcoin za dokon?anje</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Napaka pri nalaganju wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Uvažanje podatkovne datoteke verige blokov.</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Nalagam naslove ...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Napaka: ni mogo?e zagnati vozliš?a</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Navezava v %s  na tem ra?unalniku ni mogo?a Gridcoin aplikacija je verjetno že zagnana.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Na tem ra?unalniku je bilo nemogo?e vezati na %s (bind returned error %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Napaka: Zaklenjena denarnica, ni mogo?e opraviti transakcije</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Napaka: Ta transakcija zahteva transakcijsko provizijo vsaj %s zaradi svoje koli?ine, kompleksnosti ali uporabo sredstev, ki ste jih prejeli pred kratkim. </translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Pošiljanje...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Neveljavna koli?ina</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Opozorilo: Prosimo preverite svoj datum in ?as svojega ra?unalnika! ?e je vaša ura nastavljena napa?no Gridcoin ne bo deloval.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Opozorilo: Malo prostora na disku!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Neznano omrežje določeno v -onlynet: '%s'.</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Premalo sredstev</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Nalagam kazalo blokov ...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Nalagam denarnico ...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Ni mogoče zapisati privzetega naslova</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Ponovno pregledujem verigo ...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Nalaganje končano</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
</context>
</TS>